﻿Imports Infragistics.Windows.DataPresenter
Imports System.Collections.ObjectModel
Imports System.ComponentModel
Imports System.Data
Imports Infragistics.Windows.DataPresenter.Events
Imports System.Windows.Markup
Imports System.Threading

Public Class MockGrid
    Inherits XamDataGrid

    Private Sub MockGrid_Initialized(ByVal sender As Object, ByVal e As EventArgs) Handles Me.Initialized
        Me.Theme = "Generic"

        Me.FieldLayoutSettings.AutoGenerateFields = False
        Me.FieldLayoutSettings.AllowFieldMoving = AllowFieldMoving.Yes
        Me.FieldLayoutSettings.AutoArrangeCells = AutoArrangeCells.Never
        Me.FieldLayoutSettings.ExpansionIndicatorDisplayMode = ExpansionIndicatorDisplayMode.Never
        Me.FieldLayoutSettings.HeaderPlacement = HeaderPlacement.OnTopOnly
        Me.FieldLayoutSettings.HeaderPlacementInGroupBy = HeaderPlacementInGroupBy.OnTopOnly

        Me.FieldLayoutSettings.RecordSelectorLocation = RecordSelectorLocation.None
        Me.FieldLayoutSettings.SelectionTypeCell = Infragistics.Windows.Controls.SelectionType.None
        Me.FieldLayoutSettings.SelectionTypeField = Infragistics.Windows.Controls.SelectionType.None
        Me.FieldLayoutSettings.SelectionTypeRecord = Infragistics.Windows.Controls.SelectionType.Extended

        Me.FieldLayoutSettings.FilterUIType = FilterUIType.LabelIcons
        Me.FieldLayoutSettings.AutoFitMode = AutoFitMode.Never

        Me.FieldSettings.ExpandableFieldRecordHeaderDisplayMode = ExpandableFieldRecordHeaderDisplayMode.NeverDisplayHeader
        Me.FieldSettings.CellClickAction = CellClickAction.SelectRecord
        Me.FieldSettings.AllowEdit = False
        Me.FieldSettings.AllowRecordFiltering = True
        Me.FieldSettings.LabelClickAction = LabelClickAction.SortByMultipleFields
        Me.FieldSettings.CellVisibilityWhenGrouped = Windows.Visibility.Collapsed


        Me.SetupFields()

        Dim source As Countries = New Countries(Me)
        Me.DataSource = source

        source.GetData()
    End Sub

    Public Sub SetupFields()
        ' Create a new 'top level' countries field layout.
        Dim layout As New FieldLayout
        Me.FieldLayouts.Add(layout)

        ' Add a field for the country name.
        Dim countryName As New UnboundField
        countryName.Name = "Country"
        countryName.BindingPath = New PropertyPath("Country")
        layout.Fields.Add(countryName)

        ' Add a field for the child cities.
        Dim cities As New UnboundField
        cities.Name = "Cities"
        cities.BindingPath = New PropertyPath("Cities")
        cities.DataType = Type.GetType("System.Collections.IEnumerable")
        layout.Fields.Add(cities)


        ' Create a 'child' level field layout for cities.
        Dim childLayout As New FieldLayout
        Me.FieldLayouts.Add(childLayout)

        ' Turn headers off for child grids.
        childLayout.Settings.LabelLocation = LabelLocation.Hidden

        ' Indent the children by increasing the left margin or the DataRecordPresenter
        Dim s As New Style(GetType(DataRecordPresenter))
        s.Setters.Add(New Setter(DataRecordPresenter.MarginProperty, New Thickness(30, 0, 0, 0)))
        childLayout.Settings.DataRecordPresenterStyle = s

        ' Add a field for the city name.
        Dim cityName As New UnboundField
        cityName.Name = "City"
        cityName.BindingPath = New PropertyPath("City")
        childLayout.Fields.Add(cityName)
    End Sub

    Private Sub MockGrid_AssigningFieldLayoutToItem(ByVal sender As Object, ByVal e As AssigningFieldLayoutToItemEventArgs) Handles Me.AssigningFieldLayoutToItem
        If TypeOf e.Item Is Country Then
            e.FieldLayout = Me.FieldLayouts(0)
        Else
            e.FieldLayout = Me.FieldLayouts(1)
        End If
    End Sub

    Private Sub MockGrid_InitializeRecord(ByVal sender As Object, ByVal e As Infragistics.Windows.DataPresenter.Events.InitializeRecordEventArgs) Handles Me.InitializeRecord
        Select Case e.Record.RecordType
            Case RecordType.DataRecord
                Dim rec As DataRecord = DirectCast(e.Record, DataRecord)
                rec.IsExpanded = True
        End Select
    End Sub




    Private Class Countries
        Inherits ObservableCollection(Of Country)

        Private grid As MockGrid

        Public Sub New(ByVal grid As MockGrid)
            Me.grid = grid
        End Sub

        Public Sub GetData()
            Dim c As Country

            c = New Country("England")
            c.Cities.Add(New City("London"))
            c.Cities.Add(New City("Cambridge"))
            c.Cities.Add(New City("Oxford"))
            c.Cities.Add(New City("Peterborough"))
            Me.Add(c)

            c = New Country("Scotland")
            c.Cities.Add(New City("Aberdeen"))
            c.Cities.Add(New City("Dundee"))
            c.Cities.Add(New City("Endinburgh"))
            c.Cities.Add(New City("Glasgow"))
            c.Cities.Add(New City("Inverness"))
            c.Cities.Add(New City("Stirling"))
            Me.Add(c)

            c = New Country("Wales")
            c.Cities.Add(New City("Cardiff"))
            c.Cities.Add(New City("Newport"))
            c.Cities.Add(New City("Swansea"))
            c.Cities.Add(New City("Bangor"))
            Me.Add(c)
        End Sub
    End Class


    Private Class Country
        Private _country As String
        Private _cities As New ObservableCollection(Of City)

        Public Sub New(ByVal country As String)
            Me._country = country
        End Sub

        Public Property Country() As String
            Get
                Return Me._country
            End Get
            Set(ByVal value As String)
                Me._country = value
            End Set
        End Property

        Public Property Cities() As ObservableCollection(Of City)
            Get
                Return Me._cities
            End Get
            Set(ByVal value As ObservableCollection(Of City))
                Me._cities = value
            End Set
        End Property
    End Class

    Private Class City
        Private _city As String

        Public Sub New(ByVal city As String)
            Me._city = city
        End Sub

        Public Property City() As String
            Get
                Return Me._city
            End Get
            Set(ByVal value As String)
                Me._city = value
            End Set
        End Property
    End Class


End Class
